FrameView

Struct FrameView 

pub struct FrameView<'a> {
    pub simbox: Option<&'a SimBox>,
    pub meta: &'a HashMap<String, String>,
    /* private fields */
}
A borrowed, read-only view of a Frame.

Block keys are &str references into the original Frame’s key strings. Block values are BlockViews that borrow the underlying column data. simbox and meta are borrowed by reference.

Fields

simbox: Option<&'a SimBox>

Borrowed simulation box, if present.

meta: &'a HashMap<String, String>

Borrowed metadata map.

Implementations

Source

impl<'a> FrameView<'a>

pub fn from_parts( map: HashMap<&'a str, BlockView<'a>>, simbox: Option<&'a SimBox>, meta: &'a HashMap<String, String>, ) -> FrameView<'a>

Construct a FrameView from parts.

pub fn get(&self, key: &str) -> Option<&BlockView<'a>>

Gets an immutable reference to the block view for key if present.

pub fn iter(&self) -> impl Iterator<Item = (&&'a str, &BlockView<'a>)>

Returns an iterator over (&str, &BlockView).

pub fn keys(&self) -> impl Iterator<Item = &&'a str>

Returns an iterator over block keys.

pub fn values(&self) -> impl Iterator<Item = &BlockView<'a>>

Returns an iterator over block view references.

pub fn len(&self) -> usize

Number of blocks in the view.

pub fn is_empty(&self) -> bool

Returns true if the view contains no blocks.

pub fn contains_key(&self, key: &str) -> bool

Returns true if the view contains the specified block key.

pub fn to_owned(&self) -> Frame

Creates an owned Frame by cloning all viewed data.