MolRec

Struct MolRec 

pub struct MolRec {
    pub meta: Value,
    pub frame: Frame,
    pub trajectory: Option<Trajectory>,
    pub observables: BTreeMap<String, ObservableRecord>,
    pub method: Value,
    pub parameters: Value,
}
Single logical MolRec object.

Fields

meta: Value

Record-level metadata.

frame: Frame

Canonical frame.

trajectory: Option<Trajectory>

Optional trajectory states.

observables: BTreeMap<String, ObservableRecord>

Named observables.

method: Value

Method-level metadata.

parameters: Value

Parameter metadata.

Implementations

Source

impl MolRec

pub fn new(frame: Frame) -> MolRec

Create a MolRec around one canonical frame.

pub fn from_frames(frame: Frame, frames: Vec<Frame>) -> MolRec

Build a MolRec from one canonical frame plus explicit trajectory states.

pub fn from_trajectory(trajectory: Trajectory) -> Result<MolRec, MolRsError>

Build a MolRec from a dedicated trajectory object.

The canonical frame defaults to the first trajectory frame.

pub fn count_frames(&self) -> usize

Total number of accessible frames.

pub fn frame_at(&self, index: usize) -> Option<Frame>

Return one accessible frame.

pub fn set_frame(&mut self, frame: Frame)

Replace the canonical frame.

pub fn add_frame(&mut self, frame: Frame)

Append one frame to the trajectory, creating it if needed.

pub fn set_trajectory(&mut self, trajectory: Option<Trajectory>)

Replace the trajectory.

pub fn add_observable( &mut self, observable: ObservableRecord, ) -> Option<ObservableRecord>

Insert or replace an observable by name.

pub fn get_observable(&self, name: &str) -> Option<&ObservableRecord>

Borrow an observable by name.

pub fn remove_observable(&mut self, name: &str) -> Option<ObservableRecord>

Remove an observable by name.