pub struct FrameView<'a> {
pub simbox: Option<&'a SimBox>,
pub meta: &'a HashMap<String, String>,
/* private fields */
}Expand description
Fields
simbox: Option<&'a SimBox>Borrowed simulation box, if present.
meta: &'a HashMap<String, String>Borrowed metadata map.
Implementations
Sourceimpl<'a> FrameView<'a>
impl<'a> FrameView<'a>
Sourcepub fn from_parts(
map: HashMap<&'a str, BlockView<'a>>,
simbox: Option<&'a SimBox>,
meta: &'a HashMap<String, String>,
) -> FrameView<'a>
pub fn from_parts( map: HashMap<&'a str, BlockView<'a>>, simbox: Option<&'a SimBox>, meta: &'a HashMap<String, String>, ) -> FrameView<'a>
Construct a FrameView from parts.
Sourcepub fn get(&self, key: &str) -> Option<&BlockView<'a>>
pub fn get(&self, key: &str) -> Option<&BlockView<'a>>
Gets an immutable reference to the block view for key if present.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&&'a str, &BlockView<'a>)>
pub fn iter(&self) -> impl Iterator<Item = (&&'a str, &BlockView<'a>)>
Returns an iterator over (&str, &BlockView).
Sourcepub fn values(&self) -> impl Iterator<Item = &BlockView<'a>>
pub fn values(&self) -> impl Iterator<Item = &BlockView<'a>>
Returns an iterator over block view references.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns true if the view contains the specified block key.